# OralB Toothbrush
[![PyPI Version](https://img.shields.io/pypi/v/OralB?label=PyPI&logo=pypi)](https://pypi.org/project/OralB/)


Async method to read information from Bluetooth OralB Toothbrush.

Exposes the following sensors:
 - Brush Time
 - Battery Life
 - Selected Mode
 - Operation status
 - Sector
 - Sector Time
